.clearfix {
  *zoom: 1;
}
.clearfix:before,
.clearfix:after {
  display: table;
  content: "";
  line-height: 0;
}
.clearfix:after {
  clear: both;
}
.hide-text {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
}
.input-block-level {
  display: block;
  width: 100%;
  min-height: 30px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.control-inset {
  width: 150px;
  height: 25px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  background: white;
  border-bottom: 1px solid white;
}
.control-textinput {
  color: #7c8c99;
  font-family: "Open Sans", sans-serif;
  font-size: 11px;
  padding: 1px 4px;
  width: 150px;
  height: 25px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  background: white;
  border-bottom: 1px solid white;
  border: none;
}
.control-textinput:hover {
  border: 1px solid #eee;
  padding: 0 3px;
}
.control-textinput:focus {
  border: 1px solid #ed930d;
  padding: 0 3px;
}
.actionlink {
  display: inline-block;
  color: #7c8c99;
  height: auto;
  line-height: normal;
  padding: 4px 0 0px;
  border-bottom: 1px dotted #99a5af;
  margin: 1px 0 3px;
  cursor: pointer;
  width: auto;
}
.actionlink:hover {
  color: #99a5af;
  border-bottom: 1px dotted #c4cbd1;
}
.changed-badge {
  position: relative;
}
.changed-badge span {
  position: absolute;
  display: block;
  z-index: 3;
  right: 2px;
  top: -5px;
  font-size: 24px;
  font-weight: bold;
  color: #ed930d;
}
.control {
  display: block;
  overflow: hidden;
  margin: 1px;
}
.control.changed {
  box-shadow: 0 0 2px #ed930d !important;
}
.control.mini {
  width: 50px !important;
}
.control.big {
  width: 240px !important;
}
.control.container {
  margin: 0;
}
.control.pad {
  padding: 10px;
}
.control.indent {
  padding: 0 10px;
}
.control.center {
  text-align: center;
}
.control.center > div {
  display: inline-block;
  margin: auto;
}
.control.right {
  float: right;
}
.control.box {
  overflow: visible;
}
.control.hc {
  white-space: nowrap;
}
.control.hc > tbody > tr > td {
  vertical-align: top;
  padding: 0;
}
.control.vc > div {
  padding-bottom: 5px;
}
.control.vc > div:last-child {
  padding-bottom: 0;
}
.control.vc.nopad > div {
  padding-bottom: 0;
}
.control.label {
  text-decoration: none;
  color: #7c8c99;
  line-height: 27px;
  width: auto;
  height: 27px;
  display: inline-block;
  word-wrap: break-word;
}
.control.label.bold {
  font-weight: bold;
}
.control.label.small {
  font-size: 9.9px;
  height: auto;
}
.control.tooltip {
  position: relative;
  display: inline-block;
  overflow: visible;
  margin: 0;
}
.control.tooltip.body {
  position: relative;
}
.control.tooltip.body > :last-child {
  display: block;
  width: 1px;
  margin-left: 10px;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.75) transparent;
  border-width: 5px 5px 0 5px;
}
.control.tooltip.body > :first-child {
  display: block;
  background: rgba(0, 0, 0, 0.75);
  color: white;
  padding: 3px 8px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.control.tooltip:hover > .tip {
  display: block;
  opacity: 1;
}
.control.icon {
  width: 16px;
  height: 27px;
  display: inline-block;
  line-height: 22px;
}
.control.icon i {
  display: block;
}
.control.icon.style-yellow i:before {
  color: #ed930d;
}
.control.button {
  width: 120px;
  height: auto;
  padding: 6px 0 5px;
  text-decoration: none;
  color: #7c8c99;
}
.control.button.style-normal {
  background-color: #fcfcfc;
  background-image: -moz-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#f8f8f8));
  background-image: -webkit-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: -o-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: linear-gradient(to bottom, #ffffff, #f8f8f8);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#fff8f8f8', GradientType=0);
  color: rgba(0, 0, 0, 0.5);
  border: none;
  font-size: 11px;
  font-weight: bold;
  text-align: center;
  text-transform: uppercase;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  -webkit-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  -moz-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  position: relative;
  top: -1px;
}
.control.button.style-normal:hover {
  background-color: #ffffff;
  background-image: -moz-linear-gradient(top, #ffffff, #ffffff);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#ffffff));
  background-image: -webkit-linear-gradient(top, #ffffff, #ffffff);
  background-image: -o-linear-gradient(top, #ffffff, #ffffff);
  background-image: linear-gradient(to bottom, #ffffff, #ffffff);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#ffffffff', GradientType=0);
}
.control.button.style-normal:active {
  background-color: #f3f3f3;
  background-image: -moz-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f8f8f8), to(#ebebeb));
  background-image: -webkit-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: -o-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: linear-gradient(to bottom, #f8f8f8, #ebebeb);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff8f8f8', endColorstr='#ffebebeb', GradientType=0);
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
}
.control.button.style-orange {
  background-color: #f09a19;
  background-image: -moz-linear-gradient(top, #f39e21, #ed930d);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f39e21), to(#ed930d));
  background-image: -webkit-linear-gradient(top, #f39e21, #ed930d);
  background-image: -o-linear-gradient(top, #f39e21, #ed930d);
  background-image: linear-gradient(to bottom, #f39e21, #ed930d);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff39e21', endColorstr='#ffed930d', GradientType=0);
  color: rgba(0, 0, 0, 0.5);
  border: none;
  font-size: 11px;
  font-weight: bold;
  text-align: center;
  text-transform: uppercase;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  -webkit-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  -moz-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  position: relative;
  top: -1px;
}
.control.button.style-orange:hover {
  background-color: #f4a52f;
  background-image: -moz-linear-gradient(top, #f4a939, #f39e21);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f4a939), to(#f39e21));
  background-image: -webkit-linear-gradient(top, #f4a939, #f39e21);
  background-image: -o-linear-gradient(top, #f4a939, #f39e21);
  background-image: linear-gradient(to bottom, #f4a939, #f39e21);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff4a939', endColorstr='#fff39e21', GradientType=0);
}
.control.button.style-orange:active {
  background-color: #e38d0c;
  background-image: -moz-linear-gradient(top, #ed930d, #d5840c);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ed930d), to(#d5840c));
  background-image: -webkit-linear-gradient(top, #ed930d, #d5840c);
  background-image: -o-linear-gradient(top, #ed930d, #d5840c);
  background-image: linear-gradient(to bottom, #ed930d, #d5840c);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffed930d', endColorstr='#ffd5840c', GradientType=0);
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
}
.control.button.style-green {
  background-color: #6eb725;
  background-image: -moz-linear-gradient(top, #73bf26, #66aa22);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#73bf26), to(#66aa22));
  background-image: -webkit-linear-gradient(top, #73bf26, #66aa22);
  background-image: -o-linear-gradient(top, #73bf26, #66aa22);
  background-image: linear-gradient(to bottom, #73bf26, #66aa22);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff73bf26', endColorstr='#ff66aa22', GradientType=0);
  color: rgba(0, 0, 0, 0.5);
  border: none;
  font-size: 11px;
  font-weight: bold;
  text-align: center;
  text-transform: uppercase;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  -webkit-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  -moz-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  position: relative;
  top: -1px;
}
.control.button.style-green:hover {
  background-color: #7acc29;
  background-image: -moz-linear-gradient(top, #80d52a, #73bf26);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#80d52a), to(#73bf26));
  background-image: -webkit-linear-gradient(top, #80d52a, #73bf26);
  background-image: -o-linear-gradient(top, #80d52a, #73bf26);
  background-image: linear-gradient(to bottom, #80d52a, #73bf26);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff80d52a', endColorstr='#ff73bf26', GradientType=0);
}
.control.button.style-green:active {
  background-color: #61a220;
  background-image: -moz-linear-gradient(top, #66aa22, #59951e);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#66aa22), to(#59951e));
  background-image: -webkit-linear-gradient(top, #66aa22, #59951e);
  background-image: -o-linear-gradient(top, #66aa22, #59951e);
  background-image: linear-gradient(to bottom, #66aa22, #59951e);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff66aa22', endColorstr='#ff59951e', GradientType=0);
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
}
.control.button.style-blue {
  background-color: #56a2df;
  background-image: -moz-linear-gradient(top, #5ea7e1, #499bdd);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#5ea7e1), to(#499bdd));
  background-image: -webkit-linear-gradient(top, #5ea7e1, #499bdd);
  background-image: -o-linear-gradient(top, #5ea7e1, #499bdd);
  background-image: linear-gradient(to bottom, #5ea7e1, #499bdd);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff5ea7e1', endColorstr='#ff499bdd', GradientType=0);
  color: rgba(0, 0, 0, 0.5);
  border: none;
  font-size: 11px;
  font-weight: bold;
  text-align: center;
  text-transform: uppercase;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  -webkit-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  -moz-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  position: relative;
  top: -1px;
}
.control.button.style-blue:hover {
  background-color: #6baee3;
  background-image: -moz-linear-gradient(top, #74b3e5, #5ea7e1);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#74b3e5), to(#5ea7e1));
  background-image: -webkit-linear-gradient(top, #74b3e5, #5ea7e1);
  background-image: -o-linear-gradient(top, #74b3e5, #5ea7e1);
  background-image: linear-gradient(to bottom, #74b3e5, #5ea7e1);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff74b3e5', endColorstr='#ff5ea7e1', GradientType=0);
}
.control.button.style-blue:active {
  background-color: #4096db;
  background-image: -moz-linear-gradient(top, #499bdd, #348fd9);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#499bdd), to(#348fd9));
  background-image: -webkit-linear-gradient(top, #499bdd, #348fd9);
  background-image: -o-linear-gradient(top, #499bdd, #348fd9);
  background-image: linear-gradient(to bottom, #499bdd, #348fd9);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff499bdd', endColorstr='#ff348fd9', GradientType=0);
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
}
.control.button.style-link {
  display: inline-block;
  color: #7c8c99;
  height: auto;
  line-height: normal;
  padding: 4px 0 0px;
  border-bottom: 1px dotted #99a5af;
  margin: 1px 0 3px;
  cursor: pointer;
  width: auto;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
.control.button.style-link:hover {
  color: #99a5af;
  border-bottom: 1px dotted #c4cbd1;
}
.control.button.style-mini {
  background-color: #fcfcfc;
  background-image: -moz-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#f8f8f8));
  background-image: -webkit-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: -o-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: linear-gradient(to bottom, #ffffff, #f8f8f8);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#fff8f8f8', GradientType=0);
  color: rgba(0, 0, 0, 0.5);
  border: none;
  font-size: 11px;
  font-weight: bold;
  text-align: center;
  text-transform: uppercase;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  -webkit-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  -moz-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  position: relative;
  top: -1px;
  min-width: 17px;
  width: auto;
  padding: 6px 5px;
}
.control.button.style-mini:hover {
  background-color: #ffffff;
  background-image: -moz-linear-gradient(top, #ffffff, #ffffff);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#ffffff));
  background-image: -webkit-linear-gradient(top, #ffffff, #ffffff);
  background-image: -o-linear-gradient(top, #ffffff, #ffffff);
  background-image: linear-gradient(to bottom, #ffffff, #ffffff);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#ffffffff', GradientType=0);
}
.control.button.style-mini:active {
  background-color: #f3f3f3;
  background-image: -moz-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f8f8f8), to(#ebebeb));
  background-image: -webkit-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: -o-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: linear-gradient(to bottom, #f8f8f8, #ebebeb);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff8f8f8', endColorstr='#ffebebeb', GradientType=0);
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
}
.control.button i {
  top: 1px;
  position: relative;
  color: black;
}
.control.button.style-icon {
  background: transparent !important;
  border: none;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  width: 14px;
  height: 14px;
  padding: 2px;
  opacity: .5;
  line-height: normal;
}
.control.button.style-icon:hover {
  opacity: 0.75;
}
.control.button.style-icon:active {
  padding: 3px 2px 1px;
}
.control.textbox {
  color: #7c8c99;
  font-family: "Open Sans", sans-serif;
  font-size: 11px;
  padding: 1px 4px;
  width: 150px;
  height: 25px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  background: white;
  border-bottom: 1px solid white;
  border: none;
}
.control.textbox:hover {
  border: 1px solid #eee;
  padding: 0 3px;
}
.control.textbox:focus {
  border: 1px solid #ed930d;
  padding: 0 3px;
}
.control.editable i:before {
  top: 1px;
}
.control.editable > .label {
  display: inline-block;
  color: #7c8c99;
  height: auto;
  line-height: normal;
  padding: 4px 0 0px;
  border-bottom: 1px dotted #99a5af;
  margin: 1px 0 3px;
  cursor: pointer;
  width: auto;
}
.control.editable > .label:hover {
  color: #99a5af;
  border-bottom: 1px dotted #c4cbd1;
}
.control.checkbox {
  white-space: nowrap;
}
.control.checkbox > .label {
  float: left;
}
.control.checkbox > input {
  float: left;
  display: none;
}
.control.checkbox > input + label {
  float: left;
  margin: 6px 7px 0 1px;
  width: 15px;
  height: 15px;
  padding: 1px;
  background-color: #fcfcfc;
  background-image: -moz-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#f8f8f8));
  background-image: -webkit-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: -o-linear-gradient(top, #ffffff, #f8f8f8);
  background-image: linear-gradient(to bottom, #ffffff, #f8f8f8);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#fff8f8f8', GradientType=0);
  color: rgba(0, 0, 0, 0.5);
  border: none;
  font-size: 11px;
  font-weight: bold;
  text-align: center;
  text-transform: uppercase;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  -webkit-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  -moz-box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  box-shadow: 0 1px 0px rgba(0, 0, 0, 0.125);
  position: relative;
  top: -1px;
}
.control.checkbox > input + label:hover {
  background-color: #ffffff;
  background-image: -moz-linear-gradient(top, #ffffff, #ffffff);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#ffffff));
  background-image: -webkit-linear-gradient(top, #ffffff, #ffffff);
  background-image: -o-linear-gradient(top, #ffffff, #ffffff);
  background-image: linear-gradient(to bottom, #ffffff, #ffffff);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#ffffffff', GradientType=0);
}
.control.checkbox > input + label:active {
  background-color: #f3f3f3;
  background-image: -moz-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f8f8f8), to(#ebebeb));
  background-image: -webkit-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: -o-linear-gradient(top, #f8f8f8, #ebebeb);
  background-image: linear-gradient(to bottom, #f8f8f8, #ebebeb);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff8f8f8', endColorstr='#ffebebeb', GradientType=0);
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
}
.control.checkbox > input + label:active {
  padding: 2px 1px 0;
}
.control.checkbox > input + label .tick {
  -webkit-transition: 0.5s;
  -moz-transition: 0.5s;
  -o-transition: 0.5s;
  transition: 0.5s;
  opacity: 0;
}
.control.checkbox > input:checked + label {
  background-color: #f4b353;
  background-image: -moz-linear-gradient(top, #f8c881, #ed930d);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f8c881), to(#ed930d));
  background-image: -webkit-linear-gradient(top, #f8c881, #ed930d);
  background-image: -o-linear-gradient(top, #f8c881, #ed930d);
  background-image: linear-gradient(to bottom, #f8c881, #ed930d);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff8c881', endColorstr='#ffed930d', GradientType=0);
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
  box-shadow: 0 1px 1px rgba(0,0,0,0.25) inset, 0 1px 1px rgba(255,255,255,0.125);
}
.control.checkbox > input:checked + label .tick {
  opacity: .5;
}
.control.checkbox .label {
  margin: 0;
}
.control.dropdown {
  /*line-height: @controlHeight;
		padding: 1px 5px 1px !important;
		text-decoration: none;
		color: @controlText;
		.button-style(#ddd);*/

  width: 160px;
  height: 29px;
  /*text-transform: none;
    	-webkit-appearance: none;*/

}
.control.combobox {
  color: #7c8c99;
  font-family: "Open Sans", sans-serif;
  font-size: 11px;
  padding: 1px 4px;
  width: 150px;
  height: 25px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  background: white;
  border-bottom: 1px solid white;
  border: none;
}
.control.combobox:hover {
  border: 1px solid #eee;
  padding: 0 3px;
}
.control.combobox:focus {
  border: 1px solid #ed930d;
  padding: 0 3px;
}
.control.formline > div:first-child {
  width: 120px;
  text-align: right;
  padding-right: 20px;
  float: left;
}
.control.formline > div:last-child {
  float: left;
}
.control.formline > div {
  padding: 1px;
}
.control.formgroup > div:first-child {
  color: #b5bec6;
  text-transform: uppercase;
  font-weight: bold;
  border-bottom: 1px solid #b5bec6;
}
.control.formgroup > div:last-child {
  padding: 10px 0;
}
.control.collapse > .header {
  cursor: pointer;
}
.control.collapserow {
  padding: 0 !important;
}
.control.collapserow > .header {
  padding: 5px;
}
.control.collapserow > .header:hover {
  background: #fff;
}
.control.collapserow > .children,
.control.collapserow > * > .children {
  background: white !important;
  padding: 5px;
}
.control.list {
  width: 150px;
  height: 25px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  -moz-box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  box-shadow: 0 1px 1px rgba(0,0,0,0.2) inset, 0 1px 1px rgba(255,255,255,0.2), 0 1px 0 rgba(0,0,0,0.04);
  background: white;
  border-bottom: 1px solid white;
  width: auto;
  height: auto;
}
.control.list > div {
  border-bottom: 1px solid #eee;
}
.control.list > div:last-child {
  border-bottom: none;
}
.control.listitem {
  padding: 0 5px;
}
.control.listitem:active {
  background-color: #f2a636;
  background-image: -moz-linear-gradient(top, #f5b351, #ed930d);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f5b351), to(#ed930d));
  background-image: -webkit-linear-gradient(top, #f5b351, #ed930d);
  background-image: -o-linear-gradient(top, #f5b351, #ed930d);
  background-image: linear-gradient(to bottom, #f5b351, #ed930d);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff5b351', endColorstr='#ffed930d', GradientType=0);
  color: #8c5708;
}
.control.listitem:active * {
  color: white;
  text-shadow: 0 1px 0px rgba(255, 255, 255, 0.6);
}
.control.table {
  display: table;
  margin: 1px;
  width: 99%;
  border-spacing: 0;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.25);
  -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.25);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.25);
  -webkit-border-radius: 1px;
  -moz-border-radius: 1px;
  border-radius: 1px;
}
.control.table.compressed > tbody > tr > td {
  padding: 0 5px;
}
.control.table > tbody {
  margin: 0;
}
.control.table > tbody > tr {
  margin: 0;
}
.control.table > tbody > tr > th {
  color: #7c8c99;
}
.control.table > tbody > tr > td {
  background: #fcfcfc;
  border: 1px solid #f0f0f0;
  border-width: 1px 0 0 1px;
  padding: 5px;
  vertical-align: top;
}
.control.table > tbody > tr:first-child td {
  border-top: none;
}
.control.table > tbody > tr > *:first-child {
  border-left: none !important;
}
.control.table > tbody > tr > th {
  background: #fcfcfc;
  padding: 10px 7px;
  border-top: 1px solid #f0f0f0;
  border-left: 1px solid #e3e3e3;
  background-color: #f4f4f4;
  background-image: -moz-linear-gradient(top, #f6f6f6, #f0f0f0);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f6f6f6), to(#f0f0f0));
  background-image: -webkit-linear-gradient(top, #f6f6f6, #f0f0f0);
  background-image: -o-linear-gradient(top, #f6f6f6, #f0f0f0);
  background-image: linear-gradient(to bottom, #f6f6f6, #f0f0f0);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff6f6f6', endColorstr='#fff0f0f0', GradientType=0);
  font-weight: bold;
  text-shadow: 0 1px 0 white;
  text-align: left;
}
.control.table > tbody > tr > th:last-child {
  border-right-width: 0px;
}
.control.layout-table > tbody > tr > td {
  padding: 0 5px;
}
.control.progressbar {
  margin: 8px 1px;
  height: 14px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  background: #ccc;
}
.control.progressbar div.fill {
  height: 14px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  background-color: #f2a636;
  background-image: -moz-linear-gradient(top, #f5b351, #ed930d);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f5b351), to(#ed930d));
  background-image: -webkit-linear-gradient(top, #f5b351, #ed930d);
  background-image: -o-linear-gradient(top, #f5b351, #ed930d);
  background-image: linear-gradient(to bottom, #f5b351, #ed930d);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff5b351', endColorstr='#ffed930d', GradientType=0);
  position: relative;
  overflow: hidden;
}
.control.paging {
  overflow: hidden;
  padding: 5px 0;
}
.control.paging * {
  float: left;
}
.control.paging .select2-container {
  margin: 0 5px;
}
.control.paging .select2-container .select2-choice {
  width: 70px;
}
.control.pathbox {
  overflow: hidden;
}
.control.pathbox > * {
  float: left;
}
