(function(){var a;a=(function(){function b(){}b.prototype.configure=function(d,f,c,e){this.enabled=d;this.os=f;this.version=c;this.edition=e;return mixpanel.init(this.token)};b.prototype.emit=function(c,d){if(this.enabled){if(d==null){d={}}d.os=this.os;d.version=this.version;d.edition=this.edition;return mixpanel.track(c,d)}};return b})();window.Feedback=new a();window.Feedback.token="b5e6ddf58b2d02245a7a19005d1cec48"}).call(this);