@import "../../../main/content/css/mixins.i.less";
@import "../../../main/content/css/vars.i.less";

.control {
    &.dashboard-dash {
        >.container {
            float: left;
            padding-top: 10px;
            width: 394px;
            min-height: 200px;

            &.container-1 {
                padding-left: 10px;
                margin: 0 -1px 0 0;
            }

            >.placeholder {
                border: 1px dashed #68a;
                height: 40px;
                width: 100%;
                padding: 10px 5px;
                margin: 5px 0;
                box-sizing: border-box;
            }

            &.trash {
                display: none;
                
                border: 1px dashed #a86;
                box-sizing: border-box;

                width: 100%;
                font-weight: bold;
                padding: 20px 0;
                text-align: center;
                float: none;
                clear: both;
                min-height: 0;

                i:before {
                    color: #a86;
                    font-size: 60px;
                }

                .placeholder {
                    display: none;
                }

            }
        }
    }

    &.dashboard-widget {
        padding: 10px 5px 10px 4px;
        box-sizing: border-box;
        //border: 1px solid #ddd;
        border-radius: 3px;
        box-shadow: 0 1px 1px rgba(0,0,0,.25);
        background: white;
        margin: 0 0 10px;

        >.handle {
            width: 8px;
            height: 30px;
            background: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAYAAAAGCAYAAADgzO9IAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH2wkeCyEzNuGfhQAAABl0RVh0Q29tbWVudABDcmVhdGVkIHdpdGggR0lNUFeBDhcAAAAVSURBVAjXYzh9+vR/BnyAeAXUMwoAFlwUQUDbs/QAAAAASUVORK5CYII=') repeat;
            float: left;
            margin: 0 5px 0 5px;
            opacity: 0;
            cursor: move;
        }

        &:hover>.handle {
            opacity: .75;
        }

        >.content {
            float: left;
        }

        &.ui-sortable-helper {
            background: white;
            box-shadow: 0 0 15px rgba(0,0,0,.25);
        }
    }

    .label.dashboard-host {
        font-size: 20px;
        margin: 0 0 0 10px;
        font-weight: bold;
        color: rgba(255,255,255,.75);
        text-shadow: 0 -1px 0 rgba(0,0,0,.5);
    }

    &.dashboard-header {
        
        &>.icon {
            float: left;

            .size(60px,60px);
            margin: 10px;
            .border-radius(2px);
            border: 1px solid rgba(0,0,0,.25);
            .box-shadow(0 0 2px white inset);

            position: relative;

            &.ubuntu {
                @ubuntuOrange: saturate(lighten(@orange, 5%), 10%);
                #gradient > .radial(lighten(@ubuntuOrange, 20%), @ubuntuOrange);
                >.image.ubuntu { display: block; }
            }

            &.debian {
                @red: #d70751;
                #gradient > .radial(lighten(@red, 20%), @red);
                >.image.debian { display: block; }
            }

            &.centos {
                @purple: #932279;
                #gradient > .radial(lighten(@purple, 20%), @purple);
                >.image.centos { display: block; }
            }

            &.rhel {
                @red: #f00;
                #gradient > .radial(lighten(@red, 20%), @red);
                >.image.rhel { display: block; }
            }

            &.freebsd {
                @red: #f00;
                #gradient > .radial(lighten(@red, 20%), @red);
                >.image.freebsd { display: block; }
            }


            >.bar {
                position: absolute;
                width: 62px;
                padding: 4px 0 5px;
                bottom: -1px;
                left: -1px;
                border-top: 1px solid rgba(0,0,0,.5);
                .border-radius(0 0 2px 2px);
                #gradient > .vertical(#666,#555);
                .box-shadow(0 1px 0px rgba(255,255,255,.25) inset);
                
                color: white;
                text-shadow: 0 -1px 0 rgba(0,0,0,.5);
                text-transform: uppercase;
                text-align: center;
                font-weight: bold;
                font-size: 10px;
            }

            >.image {
                .square(32px);
                position: absolute;
                left: 50%;
                top: 30%;
                margin: -16px;
                display: none;
            }
        }

        &>.labels {
            float: left;
            padding: 8px 0 0;

            .hostname {
                font-size: 24px;
                color: #888;
                text-shadow: 0 1px 0 #eee;
                font-weight: bold;
            }

            .distro {
                font-size: 16px;
                color: #aaa;
            }
        }

        &>.inner {
            float: right;
            padding: 20px;
        }
    }

    &.welcome {
        width: 350px;
        color: #444;
    }
}

