.control {
	&.main-page {
		min-height: 100%;
		//position: relative;

		.feedback {
			position: absolute;
			left: -150px;
			top: 30px;
			background: rgba(0,0,0,.125);
			border-radius: 5px;
			margin: 0 0 0 150px;
			width: 145px;

			.activate {
				display: inline-block;
    			font-family: 'PT Sans', sans-serif;
    			font-size: 14px;
    			font-weight: bold;
    			color: #555;
    			padding: 0 20px;
    			line-height: @headerHeight;

    			&:hover {
    				background: rgba(255,255,255,.25);
    			}
    		}

    		.box {
    			z-index: 99;
    			overflow: hidden;
    			box-shadow: 0 1px 2px black;
    			padding: 5px 10px;
    			position: absolute;
    			top: @headerHeight;
    			left: 0;
    			background: white;
    		}
		}

		&>.header {
			#gradient > .vertical(#333, #222);
			height: @headerHeight;
		    .box-shadow(0 0 5px rgba(0,0,0,0.5));

		    &>.container {
				margin: 0 auto;
		    	width: 960px;
	    		position: relative;
		    }
		}

		&>.content-wr {
		    min-height: 100%;
		    height: auto !important;
		    overflow: hidden;
		    position: relative;
			padding: 10px 0;
			//border-top: 1px solid rgba(255,255,255,.125);

			&>.content {
				margin: 0 auto @footerHeight + 10px;
		    	width: 960px;
			}
		}
	}

	&.main-sections-category {
		>div:first-child {
			font-weight: bold;
			
			.ui-dark & {
				color: #333;
				text-shadow: 0 1px 0 #777;
			}
			
			.ui-light & {
				color: #aaa;
			}
			
			text-transform: uppercase;
		}
	}

	&.main-sections-root {
		padding: 0 0 2px;

		&>.sidebar {
			float: left;
			width: 150px;
			padding: 10px 0 0;
			line-height: @fontSize + 10px;
			font-weight: bold;
			
			.tab {
				display: block;
				text-decoration: none;
				color: #888;

				.ui-dark & {
					text-shadow: 0 1px 1px #333;
				}

				padding: 1px 10px 0;
				margin: 3px 0;
				.border-radius(3px);

				i:before {
					width: 14px;
					top: -2px;
					color: #888;
					opacity: 1;
				}

				i.icon-spin {
					float: right;
					display: none;
				}

				&:hover {
					background: rgba(0,0,0,0.05);
				}

				&.active {
					#gradient > .vertical(lighten(@orange, 15%), @orange);
					color: darken(@orange, 20%);
					.box-shadow(@controlShadowHighlight);
					text-shadow: 0 1px 0px rgba(255,255,255,.60);

					i:before {
						text-shadow: 0 1px 0px rgba(255,255,255,.60);
						color: darken(@orange, 20%);
					}
				}
			}
		}

		&>.main {
			overflow: hidden;

			margin: 0 0 0 10px;
			float: left;

			.section {
				display: none;

				
				
				width: 798px;
				margin: 0 1px 1px;
			
				&.active {
					display: block;
				}
			}
		}
	}

	&.section-body {
		margin: 1px !important;
		clear: both;
		.content-gradient();
		.border-radius(3px);
		.box-shadow(@mainPaneShadow);
	}
}