.button-style(@g1) {
    #gradient > .vertical(lighten(@g1, 5%), @g1);
    color: rgba(0,0,0,.5);
    border: none;

    &:hover {
        #gradient > .vertical(lighten(@g1, 10%), lighten(@g1, 5%));
    }

    &:active {
        #gradient > .vertical(@g1, darken(@g1, 5%));    
        //padding: 2px 0 0;
        .box-shadow(@controlShadowHighlightPressed);
    }

    font-size: @fontSizeSmaller;
    font-weight: bold;
    text-align: center;
    text-transform: uppercase;

    .border-radius(3px);
    border: 1px solid rgba(0,0,0,.15);
    .box-shadow(@controlShadowHighlight);

    position: relative;
    top: -1px;
}

.control-inset {
    .size(@controlHeight - 2px, @controlWidth2 - 10px);
    .border-radius(3px);
    .box-shadow(@controlInputShadowHighlight);
    background: white;
    border-bottom: 1px solid white;
}